@@ -1,13 +1,44 @@
 import os
 import sys
 import pipes
+import subprocess
+import platform
+
+WINDOWS = platform.system() == "Windows"
+
+
+
+## Packagers beware: Hard coded paths
+
+if not WINDOWS:
+    template = "/usr/share/bm/bm-match-config"
+    BLOG_SHARE = "/usr/share/blog/"
+    DEFAULT_EDITOR = "/etc/alternatives/editor"
+
+    # This should ideally be moved to a separate package..btools-data?
+    pattern_collections = { "movies" : "/usr/share/bm/movies.patterns",
+                            "tv" : "/usr/share/bm/tv.patterns",
+                            "albums": "/usr/share/bm/albums.patterns",
+                            "artists" : "/usr/share/bm/artists.patterns"}
+else:
+    pf = os.environ["PROGRAMFILES"]
+    template = os.path.join(pf, "btools", "bm-match", "bm-match-config")
+    BLOGSHARE = os.path.join(pf, "btools", "blog", "")
+    DEFAULT_EDITOR = "notepad"
+    pattern_collections = { "movies" : os.path.join(pf, "btools", "bm-match", "movies.patterns")}
+
 
 
-loglevel = 4
-template = "/usr/share/bm/bm-match-config"
 
 VERSION = "1.0rc4"
-OUTPUT_COLOR = True
+
+
+# Disable color codes on Windows
+if not WINDOWS:
+    OUTPUT_COLOR = True
+else:
+    OUTPUT_COLOR = False
+
 
 RED = "\033[0;31m"
 GREEN = "\033[0;32m"
@@ -27,13 +58,7 @@ theme = themes[0]
 
 
 
-pattern_collections = { "movies" : "/usr/share/bm/movies.patterns",
-                        "tv" : "/usr/share/bm/tv.patterns",
-                        "albums": "/usr/share/bm/albums.patterns",
-                        "artists" : "/usr/share/bm/artists.patterns"}
-
-
-BLOG_SHARE = "/usr/share/blog/"
+loglevel = 4
 
 
 def debug(msg):
@@ -53,6 +78,7 @@ def error(msg):
     os.sys.exit(1)
 
 
+
 def get_conf_location():
     if os.path.exists(".bm-match"):
         return os.path.realpath("./.bm-match")
@@ -143,3 +169,11 @@ def cli_command_help(args, cmd):
                 print "Usage: %s %s" % (fmt % ", ".join(c[0]) , c[1])
                 print "      ", c[2]
 
+def default_editor():
+    return os.environ.get("EDITOR", DEFAULT_EDITOR)
+
+
+def edit_file(file):
+    subprocess.Popen("%s %s" % (default_editor(), 
+                                pipes.quote(file)),
+                    shell=True).wait()
